# musx
musx (pronounced *muse ex*) is a package for composing and processing symbolic music information. It contains a large set of compositional tools adapted from my Common Music and Grace systems, including support for complex pattern generation, randomness, mapping, enveloping, spectral composition, and microtonality. The musx package currently provides back ends to read and write midi files and Csound (thank you Michael Gogins!) and it is straightforward to add other backends to connect to different systems,  for example to send data to an application via portmidi, or to SuperCollider via Open Sound Control (OSC). If you are new to musx or Python, you can find installation instructions, [documentation](https://musx-admin.github.io/musx/) and demos on the [website](https://github.com/ricktaube/musx).

<hr/>
Rick Taube  

Chair, Composition/Theory<br/>
School of Music<br/>
University of Illinois Urbana-Champaign<br/>
Email: taube@illinois.edu<br/>
President, Illiac Software Inc.<br/>
https://harmonia.illiacsoftware.com/<br/>
Email: taube@illiacsoftware.com

